@@ -8,7 +8,9 @@ import psycopg2.extensions
 import psycopg2.extras
 import singer
 import singer.schema
-from c8connector import C8Connector, ConfigProperty, Sample, Schema, AttributeType, Attribute
+from c8connector import (
+    C8Connector, ConfigProperty, Sample, Schema,
+    ConfigAttributeType, SchemaAttributeType, SchemaAttribute)
 from singer import utils, metadata, get_bookmark
 from singer.catalog import Catalog
 
@@ -485,7 +487,7 @@ class PostgresSourceConnector(C8Connector):
             s_schema = stream['schema']
             for k, v in s_schema['properties'].items():
                 t = v['type'][-1]
-                s_attribs.append(Attribute(k, self.get_attribute_type(t)))
+                s_attribs.append(SchemaAttribute(k, self.get_attribute_type(t)))
             schema = Schema(stream['stream'], s_attribs)
             results.append(Sample(
                 schema=schema,
@@ -503,82 +505,82 @@ class PostgresSourceConnector(C8Connector):
             s_schema = stream['schema']
             for k, v in s_schema['properties'].items():
                 t = v['type'][-1]
-                s_attribs.append(Attribute(k, self.get_attribute_type(t)))
+                s_attribs.append(SchemaAttribute(k, self.get_attribute_type(t)))
             results.append(Schema(stream['stream'], s_attribs))
         return results
 
     @staticmethod
-    def get_attribute_type(source_type: str) -> AttributeType:
+    def get_attribute_type(source_type: str) -> SchemaAttributeType:
         if source_type == 'string':
-            return AttributeType.STRING
+            return SchemaAttributeType.STRING
         elif source_type == 'integer':
-            return AttributeType.INT
+            return SchemaAttributeType.INT
         elif source_type == 'boolean':
-            return AttributeType.BOOLEAN
+            return SchemaAttributeType.BOOLEAN
         elif source_type == 'number':
-            return AttributeType.DOUBLE
+            return SchemaAttributeType.DOUBLE
         else:
-            return AttributeType.OBJECT
+            return SchemaAttributeType.OBJECT
 
     def config(self) -> list[ConfigProperty]:
         """Get configuration parameters for the connector."""
         return [
-            ConfigProperty('host', AttributeType.STRING, True, False,
+            ConfigProperty('host', ConfigAttributeType.STRING, True, False,
                            description='PostgreSQL host',
                            example='51.25.44.24'),
-            ConfigProperty('port', AttributeType.INT, True, False,
+            ConfigProperty('port', ConfigAttributeType.INT, True, False,
                            description='PostgreSQL port',
                            example='5432'),
-            ConfigProperty('user', AttributeType.STRING, True, False,
+            ConfigProperty('user', ConfigAttributeType.STRING, True, False,
                            description='PostgreSQL user',
                            example='postgres'),
-            ConfigProperty('password', AttributeType.STRING, True, False,
+            ConfigProperty('password', ConfigAttributeType.STRING, True, False,
                            description='PostgreSQL password',
                            example='password'),
-            ConfigProperty('dbname', AttributeType.STRING, True, False,
+            ConfigProperty('dbname', ConfigAttributeType.STRING, True, False,
                            description='PostgreSQL database name',
                            example='postgres'),
-            ConfigProperty('filter_schemas', AttributeType.STRING, False, False,
+            ConfigProperty('filter_schemas', ConfigAttributeType.STRING, False, False,
                            description='Scan only the specified comma-separated schemas to improve the '
                                        'performance of data extraction',
                            example='employee,department'),
-            ConfigProperty('ssl', AttributeType.STRING, False, False,
+            ConfigProperty('ssl', ConfigAttributeType.STRING, False, False,
                            description='Using SSL via postgres sslmode=`require` option. If the server does '
                                        'not accept SSL connections or the client certificate is not recognized '
                                        'the connection will fail',
                            example='false'),
-            ConfigProperty('logical_poll_total_seconds', AttributeType.INT, False, False,
+            ConfigProperty('logical_poll_total_seconds', ConfigAttributeType.INT, False, False,
                            description='Stop running the tap when no data received from wal after '
                                        'certain number of seconds',
                            example='10800'),
-            ConfigProperty('break_at_end_lsn', AttributeType.BOOLEAN, False, False,
+            ConfigProperty('break_at_end_lsn', ConfigAttributeType.BOOLEAN, False, False,
                            description='Stop running the tap if the newly received lsn is after the max '
                                        'lsn that was detected when the tap started.',
                            example='false'),
-            ConfigProperty('max_run_seconds', AttributeType.INT, False, False,
+            ConfigProperty('max_run_seconds', ConfigAttributeType.INT, False, False,
                            description='Stop running the tap after certain number of seconds',
                            example='43200'),
-            ConfigProperty('debug_lsn', AttributeType.STRING, False, False,
+            ConfigProperty('debug_lsn', ConfigAttributeType.STRING, False, False,
                            description='If set to "true" then add _sdc_lsn property to the singer messages '
                                        'to debug postgres LSN position in the WAL stream.',
                            example='false'),
-            ConfigProperty('tap_id', AttributeType.STRING, False, False,
+            ConfigProperty('tap_id', ConfigAttributeType.STRING, False, False,
                            description='ID of the pipeline/tap',
                            example=''),
-            ConfigProperty('itersize', AttributeType.INT, False, False,
+            ConfigProperty('itersize', ConfigAttributeType.INT, False, False,
                            description='Size of PG cursor iterator when doing INCREMENTAL or FULL_TABLE.',
                            example='20000'),
-            ConfigProperty('default_replication_method', AttributeType.STRING, False, False,
+            ConfigProperty('default_replication_method', ConfigAttributeType.STRING, False, False,
                            description='Default replication method to use when no one is provided in the '
                                        'catalog (Values: LOG_BASED, INCREMENTAL or FULL_TABLE).',
                            example='LOG_BASED'),
-            ConfigProperty('use_secondary', AttributeType.BOOLEAN, False, False,
+            ConfigProperty('use_secondary', ConfigAttributeType.BOOLEAN, False, False,
                            description='Use a database replica for INCREMENTAL and FULL_TABLE replication.',
                            example='false'),
-            ConfigProperty('secondary_host', AttributeType.STRING, False, False,
+            ConfigProperty('secondary_host', ConfigAttributeType.STRING, False, False,
                            description='PostgreSQL Replica host (required if use_secondary is True)',
                            example='51.25.44.25'),
-            ConfigProperty('secondary_port', AttributeType.INT, False, False,
+            ConfigProperty('secondary_port', ConfigAttributeType.INT, False, False,
                            description='PostgreSQL Replica port (required if use_secondary is True)',
                            example='51.25.44.26')
         ]
